@@ -8,12 +8,18 @@
     :copyright: Conceptual Vision Consulting LLC 2018-2019, see AUTHORS for more details.
     :license: MIT, see LICENSE for more details.
 """
+from abc import ABC
+from typing import List, Optional, TypeVar
 
-class ILoader:
+T = TypeVar('T')  # Declare type variable
+
+
+class ILoader(ABC):
     """
     Interface for data processing components that load data items.
     """
-    def load(self, correlation_id):
+
+    def load(self, correlation_id: Optional[str]) -> List[T]:
         """
         Loads data items.
 
